@@ -345,6 +345,9 @@ FileRepeated <- function(input, output, session, nfactor.limit = 20) {
     ref <- data()$ref
     out.label <- mk.lev(out)
 
+    if (tools::file_ext(input$file$name) == "sav") {
+      out.label <- mk.lev2(data()$data.old, out.label)
+    }
 
     if (!is.null(input$check_binary)) {
       if (input$check_binary) {
